@@ -4,7 +4,9 @@ extern crate thiserror;
 pub use add::*;
 pub use ard::*;
 pub use bias::*;
+pub use convolutional::*;
 pub use exponential::*;
+pub use instant::*;
 pub use linear::*;
 pub use mul::*;
 pub use periodic::*;
@@ -15,7 +17,9 @@ use std::fmt::Debug;
 pub mod add;
 pub mod ard;
 pub mod bias;
+pub mod convolutional;
 pub mod exponential;
+pub mod instant;
 pub mod linear;
 pub mod mul;
 pub mod periodic;
